/**
 * https://yz-websit.oss-cn-hangzhou.aliyuncs.com/nanyang/%E8%B7%A8%E6%B5%8F%E8%A7%88%E5%99%A8%E5%AA%92%E4%BD%93%E6%8F%92%E4%BB%B6%E4%BD%BF%E7%94%A8%E8%AF%B4%E6%98%8E.pdf
 * SDK 使用大致说明
 * 1、npm i web-control
 * 2、使用 new WebControl 实例化插件
 * 3、使用 JS_StartService 开启服务
 * 4、使用 JS_SetWindowControlCallback 注册回调
 * 5、使用 JS_CreateWnd 创建窗口
 * 6、使用 JS_DestroyWnd 销毁窗口
 * 7、使用 JS_Disconnect 断开连接
 */

/**
 * SDK
 */
export default function SDK({ id, width, height }) {
  return new Promise((resolve, reject) => {
    const ctx = {};
    const ctrl = new WebControl({
      szPluginContainer: id,
      iServicePortStart: 14430, // 固定值
      iServicePortEnd: 14439, // 固定值
      szClassId: '29DDBC9A-8AEA-4827-9C3A-805D697CF38F', // 固定值
      cbConnectSuccess: function () {
        console.log('cbConnectSuccess');

        // ctrl.SetWindowControlCallback({
        //   cbIntegrationCallBack: callback,
        // });

        ctrl
          .JS_StartService('window', {
            dllPath: './WebPreview.dll',
          })
          .then(() => {
            resolve(ctx);
          })
          .catch((err) => {
            console.error(err);
            reject(err);
          });
      },
      cbConnectError: function () {
        console.log('cbConnectError');
        reject(new Error('cbConnectError'));
      },
      cbConnectClose: function (bNormalClose) {
        console.log('cbConnectClose');
      },
    });
    ctx.ctrl = ctrl;

    // 实时预览
    function preview(params) {
      console.log('------preview-------', params);
      return ctrl.JS_CreateWnd(id, width, height).then(function (resp) {
        console.log('------JS_CreateWnd-------', resp);
        return ctrl
          .JS_RequestInterface({
            funcName: 'setPreviewLayout',
            arguments: {
              devSerialNum: params.devSerialNum,
              productKey: params.productKey,
              layout: 1,
              channels: [{ channel: params.channel, channelName: '前视' }],
              channelName: '前视',
              channel: params.channel,
            },
          })
          .then(function (oData) {
            console.log('------setPreviewLayout-------', oData);
            return ctrl
              .JS_RequestInterface({
                funcName: 'startPreview',
                arguments: {
                  url: params.url,
                  devSerialNum: params.devSerialNum,
                  productKey: params.productKey,
                  channel: params.channel,
                  streamType: params.streamType,
                  code: params.code,
                  protocol: params.protocol,
                },
              })
              .then((res) => {
                console.log('------startPreview-------', res);
              });
          });
      });
    }
    ctx.preview = preview;

    // 停止播放
    function stopPreview() {
      ctrl.JS_RequestInterface({
        funcName: 'stopAllPreview',
        arguments: {},
      });
      ctrl.JS_DestroyWnd();
    }
    ctx.stopPreview = stopPreview;

    // 销毁
    function destroy() {
      // 关闭所有预览
      stopPreview();
      ctrl.JS_Disconnect();
    }
    ctx.destroy = destroy;
  });
}
