import { history } from 'umi';
import { Button, DatePicker, Select } from 'antd';
import { useState, useRef, useEffect } from 'react';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import moment from 'moment';
import PageTable from '@/components/PageTable';
import MachinetySelect from '@/components/MachinetySelect';
import { getMachineryTypeList } from '@/services/machineryType';
import { getDispatchList } from '@/services/dispatch';
import { getCooperativeList } from '@/services/cooperative';

const { RangePicker } = DatePicker;
const formatterTime = (val) => {
  return val ? moment(val).format('YYYY-MM-DD') : '-';
};
const getDispatch = (val) => {
  history.push(`./dispatch.jsx?id=${val.orderId}&&did=${val.dispatch || null}`);
}
const { Option } = Select;

export default (props) => {
  const [startDate, setStartDate] = useState()
  const [endDate, setEndDate] = useState()
  const [cooperativeList, setCooperativeList] = useState([]);
  const [machineryTypeList, setMachineryTypeList] = useState([]);
  const handelChange = (date, dateStrings) => {
    setStartDate(dateStrings[0])
    setEndDate(dateStrings[1])
  }

  const ref = useRef();

  const Reset = () => {
    setStartDate()
    setEndDate()
    ref.current.reload();
  }
  useEffect(() => {
    getCooperativeList({ pageSize: 999 }).then((res) => {
      setCooperativeList(res.records);
    }).catch((err) => {
      console.log(err.message)
    });
    getMachineryTypeList({ pageSize: 999 }).then((res) => {
      setMachineryTypeList(res.records);
    }).catch((err) => {
      console.log(err.message)
    });
  }, []);
  const columns = [
    {
      title: '合作社',
      dataIndex: 'orgId',
      key: 'orgId',
      hideInTable: true,
      renderFormItem: (item, field, form) => {
        return (
          <Select>
            {cooperativeList.map((item) => (
              <Option value={item.orgId} key={item.orgId}>
                {item.name}
              </Option>
            ))}
          </Select>
        )
      }
    },
    {
      title: '农机',
      dataIndex: 'machineryId',
      key: 'machineryId',
      hideInTable: true,
      renderFormItem: (item, field, form) => {
        return (
          <MachinetySelect />
        )
      }
    },

    {
      title: '合作社名',
      dataIndex: 'orgName',
      key: 'orgName',
      search: false
    },
    {
      title: '农机名',
      dataIndex: 'machineryName',
      key: 'machineryName',
      search: false
    },
    {
      title: '农机型号',
      dataIndex: 'typeName',
      key: 'typeName',
      search: false
    },
    {
      title: '农机型号',
      dataIndex: 'typeId',
      key: 'typeId',
      hideInTable: true,
      renderFormItem: (item, field, form) => {
        return (
          <Select>
            {machineryTypeList.map((item) => (
              <Option value={item.typeId} key={item.typeId}>
                {item.name}
              </Option>
            ))}
          </Select>
        )
      }
    },
    {
      title: '下单人手机',
      dataIndex: 'phone',
      key: 'phone',
      labelWidth: 'auto'
    },
    {
      title: '需求时间',
      dataIndex: 'appointmentDate',
      key: 'appointmentDate',
      render: (t) => formatterTime(t),
      renderFormItem: (_, record) => <RangePicker placeholder={['开始日期', '结束日期']} format='YYYY-MM-DD' onChange={handelChange} />
    },
    {
      title: '下单面积',
      dataIndex: 'amount',
      key: 'amount',
      search: false,
    },
    {
      title: '费用',
      dataIndex: 'charges',
      key: 'charges',
      render: (t) => t / 100,
      search: false
    },
    {
      title: '下单时间',
      dataIndex: 'createDate',
      key: 'createDate',
      search: false,
      render: (t) => formatterTime(t),
      width: 200,
    },

    {
      title: '调度状态',
      dataIndex: 'dispatchStatus',
      key: 'dispatchStatus',
      valueType: 'select',
      valueEnum: {
        0: { text: '待调度' },
        1: { text: '已调度' }
      },
      search: false
    },
    {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      hideInTable: true,
      valueType: 'select',
      valueEnum: {
        0: { text: '待调度' },
        1: { text: '已调度' }
      },
    },
    {
      title: '操作',
      valueType: 'option',
      render: (_, record) => [
        <Button
          style={{ padding: 0 }}
          type="link"
          key={1}
          onClick={() => getDispatch(record)}
        >
          调度
        </Button>
      ],
    },
  ];

  return (
    <PageHeaderWrapper>
      <PageTable
        actionRef={ref}
        request={getDispatchList}
        // expfunc={exportPersonList}
        columns={columns}
        rowKey="orderId"
        params={{ startDate, endDate }}
        onReset={Reset}
        options={false}
        scroll={{ x: 1000 }}
      />
    </PageHeaderWrapper>
  );
};
